@@ -1,4 +1,5 @@
 from airflow_dbt_cta.hooks.dbt_hook import DbtCliHook
+from airflow.exceptions import AirflowSkipException
 from airflow.models import BaseOperator
 from airflow.utils.decorators import apply_defaults
 
@@ -8,8 +9,8 @@ class DbtBaseOperator(BaseOperator):
     Base dbt operator
     All other dbt operators are derived from this operator.
 
-    :param env: If set, passes the env variables to the subprocess handler
-    :type env: dict
+    :param env_vars: If set, passes the env_vars variables to the subprocess handler
+    :type env_vars: dict
     :param profiles_dir: If set, passed as the `--profiles-dir` argument to the `dbt` command
     :type profiles_dir: str
     :param target: If set, passed as the `--target` argument to the `dbt` command
@@ -38,11 +39,11 @@ class DbtBaseOperator(BaseOperator):
 
     ui_color = '#d6522a'
 
-    template_fields = ['env', 'vars']
+    template_fields = ['env_vars', 'vars', 'skip']
 
     @apply_defaults
     def __init__(self,
-                 env=None,
+                 env_vars=None,
                  profiles_dir=None,
                  target=None,
                  dir='.',
@@ -57,11 +58,12 @@ class DbtBaseOperator(BaseOperator):
                  full_refresh=False,
                  data=False,
                  schema=False,
+                 skip=False,
                  *args,
                  **kwargs):
         super(DbtBaseOperator, self).__init__(*args, **kwargs)
 
-        self.env = env or {}
+        self.env_vars = env_vars or {}
         self.profiles_dir = profiles_dir
         self.target = target
         self.dir = dir
@@ -76,11 +78,12 @@ class DbtBaseOperator(BaseOperator):
         self.dbt_bin = dbt_bin
         self.verbose = verbose
         self.warn_error = warn_error
+        self.skip = skip
         self.create_hook()
 
     def create_hook(self):
         self.hook = DbtCliHook(
-            env=self.env,
+            env_vars=self.env_vars,
             profiles_dir=self.profiles_dir,
             target=self.target,
             dir=self.dir,
@@ -105,6 +108,8 @@ class DbtRunOperator(DbtBaseOperator):
         super(DbtRunOperator, self).__init__(profiles_dir=profiles_dir, target=target, *args, **kwargs)
 
     def execute(self, context):
+        if self.skip:
+            raise AirflowSkipException
         self.create_hook().run_cli('run')
 
 
@@ -114,6 +119,8 @@ class DbtTestOperator(DbtBaseOperator):
         super(DbtTestOperator, self).__init__(profiles_dir=profiles_dir, target=target, *args, **kwargs)
 
     def execute(self, context):
+        if self.skip:
+            raise AirflowSkipException
         self.create_hook().run_cli('test')
 
 
@@ -124,6 +131,8 @@ class DbtDocsGenerateOperator(DbtBaseOperator):
                                                       **kwargs)
 
     def execute(self, context):
+        if self.skip:
+            raise AirflowSkipException
         self.create_hook().run_cli('docs', 'generate')
 
 
@@ -133,6 +142,8 @@ class DbtSnapshotOperator(DbtBaseOperator):
         super(DbtSnapshotOperator, self).__init__(profiles_dir=profiles_dir, target=target, *args, **kwargs)
 
     def execute(self, context):
+        if self.skip:
+            raise AirflowSkipException
         self.create_hook().run_cli('snapshot')
 
 
@@ -142,6 +153,8 @@ class DbtSeedOperator(DbtBaseOperator):
         super(DbtSeedOperator, self).__init__(profiles_dir=profiles_dir, target=target, *args, **kwargs)
 
     def execute(self, context):
+        if self.skip:
+            raise AirflowSkipException
         self.create_hook().run_cli('seed')
 
 
@@ -151,6 +164,8 @@ class DbtDepsOperator(DbtBaseOperator):
         super(DbtDepsOperator, self).__init__(profiles_dir=profiles_dir, target=target, *args, **kwargs)
 
     def execute(self, context):
+        if self.skip:
+            raise AirflowSkipException
         self.create_hook().run_cli('deps')
 
 
@@ -160,4 +175,6 @@ class DbtCleanOperator(DbtBaseOperator):
         super(DbtCleanOperator, self).__init__(profiles_dir=profiles_dir, target=target, *args, **kwargs)
 
     def execute(self, context):
+        if self.skip:
+            raise AirflowSkipException
         self.create_hook().run_cli('clean')
